@@ -22,12 +22,12 @@ module Data.Graph.Inductive.PatriciaTree
     )
     where
 
+import           Control.Arrow              (second)
 import           Data.Graph.Inductive.Graph
-import           Data.IntMap (IntMap)
-import qualified Data.IntMap as IM
+import           Data.IntMap                (IntMap)
+import qualified Data.IntMap                as IM
 import           Data.List
 import           Data.Maybe
-import           Control.Arrow(second)
 
 
 newtype Gr a b = Gr (GraphRep a b)
@@ -37,6 +37,24 @@ type Context' a b = (IntMap [b], a, IntMap [b])
 
 type UGr = Gr () ()
 
+instance (Eq a, Ord b) => Eq (Gr a b) where
+  (Gr g1) == (Gr g2) = fmap sortAdj g1 == fmap sortAdj g2
+    where
+      sortAdj (a1,n,a2) = (fmap sort a1,n,fmap sort a2)
+
+instance (Show a, Show b) => Show (Gr a b) where
+  showsPrec d g = showParen (d > 10) $
+                    showString "mkGraph "
+                    . shows (labNodes g)
+                    . showString " "
+                    . shows (labEdges g)
+
+instance (Read a, Read b) => Read (Gr a b) where
+  readsPrec p = readParen (p > 10) $ \ r -> do
+    ("mkGraph", s) <- lex r
+    (ns,t) <- reads s
+    (es,u) <- reads t
+    return (mkGraph ns es, u)
 
 instance Graph Gr where
     -- required members
